@@ -30,6 +30,7 @@ from .bettycrocker import BettyCrocker
 from .biancazapatka import BiancaZapatka
 from .bigoven import BigOven
 from .blueapron import BlueApron
+from .bluejeanchef import BlueJeanChef
 from .bodybuilding import Bodybuilding
 from .bonappetit import BonAppetit
 from .bongeats import BongEats
@@ -76,6 +77,7 @@ from .fitmencook import FitMenCook
 from .food import Food
 from .food52 import Food52
 from .foodandwine import FoodAndWine
+from .foodfidelity import FoodFidelity
 from .foodnetwork import FoodNetwork
 from .foodrepublic import FoodRepublic
 from .forksoverknives import ForksOverKnives
@@ -108,7 +110,9 @@ from .ig import IG
 from .imworthy import ImWorthy
 from .indianhealthyrecipes import IndianHealthyRecipes
 from .innit import Innit
+from .insanelygoodrecipes import InsanelyGoodRecipes
 from .inspiralized import Inspiralized
+from .izzycooking import IzzyCooking
 from .jamieoliver import JamieOliver
 from .jimcooksfoodgood import JimCooksFoodGood
 from .joyfoodsunshine import Joyfoodsunshine
@@ -119,6 +123,7 @@ from .kennymcgovern import KennyMcGovern
 from .kingarthur import KingArthur
 from .kitchenstories import KitchenStories
 from .kochbar import Kochbar
+from .kochbucher import Kochbucher
 from .koket import Koket
 from .kptncook import KptnCook
 from .kuchniadomowa import KuchniaDomowa
@@ -134,6 +139,7 @@ from .lovingitvegan import Lovingitvegan
 from .maangchi import Maangchi
 from .madensverden import MadensVerden
 from .madewithlau import MadeWithLau
+from .madsvin import Madsvin
 from .marleyspoon import MarleySpoon
 from .marmiton import Marmiton
 from .marthastewart import MarthaStewart
@@ -142,6 +148,7 @@ from .meljoulwan import Meljoulwan
 from .melskitchencafe import MelsKitchenCafe
 from .mindmegette import Mindmegette
 from .minimalistbaker import Minimalistbaker
+from .ministryofcurry import MinistryOfCurry
 from .misya import Misya
 from .mobkitchen import MobKitchen
 from .momswithcrockpots import MomsWithCrockPots
@@ -164,6 +171,7 @@ from .owenhan import OwenHan
 from .paleorunningmomma import PaleoRunningMomma
 from .panelinha import Panelinha
 from .paninihappy import PaniniHappy
+from .persnicketyplates import PersnicketyPlates
 from .pickuplimes import PickUpLimes
 from .pingodoce import PingoDoce
 from .popsugar import PopSugar
@@ -188,6 +196,7 @@ from .rosannapansino import RosannaPansino
 from .rutgerbakt import RutgerBakt
 from .sallysbakingaddiction import SallysBakingAddiction
 from .sallysblog import SallysBlog
+from .saltpepperskillet import SaltPepperSkillet
 from .saveur import Saveur
 from .seriouseats import SeriousEats
 from .simpleveganista import SimpleVeganista
@@ -202,6 +211,7 @@ from .southerncastiron import SouthernCastIron
 from .southernliving import SouthernLiving
 from .spendwithpennies import SpendWithPennies
 from .springlane import Springlane
+from .staysnatched import StaySnatched
 from .steamykitchen import SteamyKitchen
 from .streetkitchen import StreetKitchen
 from .sunbasket import SunBasket
@@ -217,10 +227,13 @@ from .tastykitchen import TastyKitchen
 from .theclevercarrot import TheCleverCarrot
 from .theexpertguides import TheExpertGuides
 from .thehappyfoodie import TheHappyFoodie
+from .thekitchencommunity import TheKitchenCommunity
 from .thekitchenmagpie import TheKitchenMagPie
 from .thekitchn import TheKitchn
+from .themodernproper import TheModernProper
 from .thenutritiouskitchen import TheNutritiousKitchen
 from .thepioneerwoman import ThePioneerWoman
+from .therecipecritic import Therecipecritic
 from .thespruceeats import TheSpruceEats
 from .thevintagemixer import TheVintageMixer
 from .thewoksoflife import Thewoksoflife
@@ -232,11 +245,13 @@ from .usapears import USAPears
 from .usdamyplate import USDAMyPlate
 from .valdemarsro import Valdemarsro
 from .vanillaandbean import VanillaAndBean
+from .vegetarbloggen import Vegetarbloggen
 from .vegolosi import Vegolosi
 from .vegrecipesofindia import VegRecipesOfIndia
 from .watchwhatueat import WatchWhatUEat
 from .weightwatchers import WeightWatchers
 from .weightwatcherspublic import WeightWatchersPublic
+from .wellplated import WellPlated
 from .whatsgabycooking import WhatsGabyCooking
 from .wholefoods import WholeFoods
 from .wikicookbook import WikiCookbook
@@ -272,6 +287,7 @@ SCRAPERS = {
     BiancaZapatka.host(): BiancaZapatka,
     BigOven.host(): BigOven,
     BlueApron.host(): BlueApron,
+    BlueJeanChef.host(): BlueJeanChef,
     Bodybuilding.host(): Bodybuilding,
     BonAppetit.host(): BonAppetit,
     BowlOfDelicious.host(): BowlOfDelicious,
@@ -319,6 +335,7 @@ SCRAPERS = {
     Food.host(): Food,
     Food52.host(): Food52,
     FoodAndWine.host(): FoodAndWine,
+    FoodFidelity.host(): FoodFidelity,
     FoodNetwork.host(): FoodNetwork,
     FoodRepublic.host(): FoodRepublic,
     ForkToSpoon.host(): ForkToSpoon,
@@ -367,7 +384,9 @@ SCRAPERS = {
     IG.host(): IG,
     IndianHealthyRecipes.host(): IndianHealthyRecipes,
     Innit.host(): Innit,
+    InsanelyGoodRecipes.host(): InsanelyGoodRecipes,
     Inspiralized.host(): Inspiralized,
+    IzzyCooking.host(): IzzyCooking,
     JamieOliver.host(): JamieOliver,
     JimCooksFoodGood.host(): JimCooksFoodGood,
     Joyfoodsunshine.host(): Joyfoodsunshine,
@@ -378,6 +397,7 @@ SCRAPERS = {
     KingArthur.host(): KingArthur,
     KitchenStories.host(): KitchenStories,
     Kochbar.host(): Kochbar,
+    Kochbucher.host(): Kochbucher,
     Koket.host(): Koket,
     KptnCook.host(): KptnCook,
     KptnCook.host(subdomain="sharing"): KptnCook,
@@ -394,6 +414,7 @@ SCRAPERS = {
     Maangchi.host(): Maangchi,
     MadensVerden.host(): MadensVerden,
     MadeWithLau.host(): MadeWithLau,
+    Madsvin.host(): Madsvin,
     MarleySpoon.host(): MarleySpoon,
     MarleySpoon.host(domain="de"): MarleySpoon,
     MarleySpoon.host(domain="com.au"): MarleySpoon,
@@ -408,6 +429,7 @@ SCRAPERS = {
     MelsKitchenCafe.host(): MelsKitchenCafe,
     Mindmegette.host(): Mindmegette,
     Minimalistbaker.host(): Minimalistbaker,
+    MinistryOfCurry.host(): MinistryOfCurry,
     Misya.host(): Misya,
     MobKitchen.host(domain="mob.co.uk"): MobKitchen,
     MobKitchen.host(domain="mobkitchen.co.uk"): MobKitchen,
@@ -431,6 +453,7 @@ SCRAPERS = {
     PaleoRunningMomma.host(): PaleoRunningMomma,
     Panelinha.host(): Panelinha,
     PaniniHappy.host(): PaniniHappy,
+    PersnicketyPlates.host(): PersnicketyPlates,
     PickUpLimes.host(): PickUpLimes,
     PingoDoce.host(): PingoDoce,
     PopSugar.host(): PopSugar,
@@ -457,6 +480,7 @@ SCRAPERS = {
     RutgerBakt.host(): RutgerBakt,
     SallysBakingAddiction.host(): SallysBakingAddiction,
     SallysBlog.host(): SallysBlog,
+    SaltPepperSkillet.host(): SaltPepperSkillet,
     Saveur.host(): Saveur,
     SeriousEats.host(): SeriousEats,
     SimpleVeganista.host(): SimpleVeganista,
@@ -471,6 +495,7 @@ SCRAPERS = {
     SouthernLiving.host(): SouthernLiving,
     SpendWithPennies.host(): SpendWithPennies,
     Springlane.host(): Springlane,
+    StaySnatched.host(): StaySnatched,
     SteamyKitchen.host(): SteamyKitchen,
     StreetKitchen.host(): StreetKitchen,
     SunBasket.host(): SunBasket,
@@ -486,12 +511,15 @@ SCRAPERS = {
     TheCleverCarrot.host(): TheCleverCarrot,
     TheExpertGuides.host(): TheExpertGuides,
     TheHappyFoodie.host(): TheHappyFoodie,
+    TheKitchenCommunity.host(): TheKitchenCommunity,
     TheKitchenMagPie.host(): TheKitchenMagPie,
     TheKitchn.host(): TheKitchn,
+    TheModernProper.host(): TheModernProper,
     TheNutritiousKitchen.host(): TheNutritiousKitchen,
     ThePioneerWoman.host(): ThePioneerWoman,
     TheSpruceEats.host(): TheSpruceEats,
     TheVintageMixer.host(): TheVintageMixer,
+    Therecipecritic.host(): Therecipecritic,
     Thewoksoflife.host(): Thewoksoflife,
     TimesOfIndia.host(): TimesOfIndia,
     TineNo.host(): TineNo,
@@ -502,10 +530,12 @@ SCRAPERS = {
     Valdemarsro.host(): Valdemarsro,
     VanillaAndBean.host(): VanillaAndBean,
     VegRecipesOfIndia.host(): VegRecipesOfIndia,
+    Vegetarbloggen.host(): Vegetarbloggen,
     Vegolosi.host(): Vegolosi,
     WatchWhatUEat.host(): WatchWhatUEat,
     WeightWatchers.host(): WeightWatchers,
     WeightWatchersPublic.host(): WeightWatchersPublic,
+    WellPlated.host(): WellPlated,
     WhatsGabyCooking.host(): WhatsGabyCooking,
     WholeFoods.host(): WholeFoods,
     WholeFoods.host(domain="co.uk"): WholeFoods,
