@@ -1,5 +1,6 @@
 # mypy: disallow_untyped_defs=False
 from ._abstract import AbstractScraper
+from ._grouping_utils import group_ingredients
 
 
 class BudgetBytes(AbstractScraper):
@@ -19,6 +20,14 @@ class BudgetBytes(AbstractScraper):
     def ingredients(self):
         return self.schema.ingredients()
 
+    def ingredient_groups(self):
+        return group_ingredients(
+            self.ingredients(),
+            self.soup,
+            ".wprm-recipe-ingredient-group h4",
+            ".wprm-recipe-ingredient",
+        )
+
     def instructions(self):
         return self.schema.instructions()
 
